ledger.PaymentTerm (Payment term) — amici1

# `ledger.PaymentTerm` (Payment term)

PaymentTerm(id, ref, name, days, months, end_of_month, printed_text, printed_text_de, printed_text_fr, name_de, name_fr)

Master tables : ledger.PaymentTerms (Payment terms)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Days (days) : Number of days to add to voucher_date.

- Months (months) : Number of months to add to voucher_date.

- End of month (end_of_month) : Whether to move voucher_date to the end of month.

- Printed text (printed_text) : Used in sales/VatProductInvoice/trailer.html as follows:

- Printed text (de) (printed_text_de) : See `<lino.core.fields.RichTextField: printed_text_de>`.

- Printed text (fr) (printed_text_fr) : See `<lino.core.fields.RichTextField: printed_text_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.ledger.models.PaymentTerm.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.ledger.models.PaymentTerm.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.ledger.models.PaymentTerm.overview`.

Referenced from contacts.Partner.payment_term

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | The reference. This must be either empty or unique.
name | Designation |
days | Days | Number of days to add to voucher_date.
months | Months | Number of months to add to voucher_date.
end_of_month | End of month | Whether to move voucher_date to the end of month.
printed_text | Printed text | Used in sales/VatProductInvoice/trailer.html as follows:
printed_text_de | Printed text (de) |
printed_text_fr | Printed text (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |